@@ -693,7 +693,7 @@ def return_families():
     return Response(json.dumps(directory_list), mimetype=JSON_MIMETYPE)
 
 
-@app.route("/calculate", methods=["POST"])
+@app.route("/calculate/", methods=["POST"])
 def post_run():
     """POST ProteinGraphML run.
     :return: Success text.
@@ -715,8 +715,8 @@ def post_run():
     else:
         positives = request.files['positives']
     # Create run directory
-    run_id = bytes.hex(os.urandom(5))
-    path = Path(app.config["USERDATA"] / run_id)
+    run_id = str(bytes.hex(os.urandom(5)))
+    path = Path(app.config["USERDATA"]) / run_id
     if path.exists() and not path.is_dir():
         app.logger.warning("Removing existing file in data path name.")
         path.unlink()
@@ -765,7 +765,7 @@ def get_results(runid):
     zipfile_path = Path(app.config["USERDATA"]) /runid / "results.zip"
     if not zipfile_path.exists():
             abort(404)
-    return Response(zipfile_path.open().read(), mimetype=ZIP_MIMETYPE)
+    return Response(zipfile_path.open('rb').read(), mimetype=ZIP_MIMETYPE)
 
 @app.route("/trees/<family>.<superfamily>/alignment", methods=["POST", "GET"])
 def post_or_get_alignment_superfamily(family, superfamily):
